@@ -6,10 +6,14 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( read_history_files uploader_history_menu add_uploader_to_history write_uploader_history_to_file );
+our @EXPORT_OK = qw( read_history_files uploader_history_menu add_uploader_to_history new_uploader_to_history_file );
 
-use List::MoreUtils qw( none );
-use Term::Choose    qw( choose );
+use List::MoreUtils  qw( any none );
+use LWP::UserAgent   qw();
+use Term::ANSIScreen qw( :cursor :screen );
+use Term::Choose     qw( choose );
+
+use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
 use App::YTDL::Helper qw( read_json write_json );
 
@@ -204,8 +208,35 @@ sub add_uploader_to_history {
     my $uploader_id = $info->{$ex}{$video_id}{uploader_id};
     return if ! length $uploader_id;
     my $uploader_url;
-    $uploader_url = 'https://www.youtube.com/user/' if $ex eq 'youtube';
-    $uploader_url = 'https://vimeo.com/'            if $ex eq 'vimeo';
+    if ( $ex eq 'youtube' ) {
+        my $user_url    = sprintf 'https://www.youtube.com/user/%s', $uploader_id;
+        my $channel_url = sprintf 'https://www.youtube.com/channel/%s', $uploader_id;
+        return if any { $user_url eq $_ || $channel_url eq $_ } keys %{$opt->{sticky}};
+        return if any { $user_url eq $_ || $channel_url eq $_ } keys %{$opt->{history}};
+        my @type = ( length $uploader_id == 24 ? ( 'channel', 'user' ) : ( 'user', 'channel' ) );
+        my $ua = LWP::UserAgent->new(
+            agent         => $opt->{useragent},
+            timeout       => $opt->{timeout},
+            show_progress => 1
+        );
+        my $url = sprintf 'https://www.youtube.com/%s/%s', $type[0], $uploader_id;
+        my $res = $ua->head( $url );
+        print up( 1 ), cldown;
+        if ( $res->is_success ) {
+            $uploader_url = sprintf 'https://www.youtube.com/%s/', $type[0];
+        }
+        else {
+            my $url = sprintf 'https://www.youtube.com/%s/%s', $type[1], $uploader_id;
+            my $res = $ua->head( $url );
+            print up( 1 ), cldown;
+            if ( $res->is_success ) {
+                $uploader_url = sprintf 'https://www.youtube.com/%s/', $type[1];
+            }
+        }
+    }
+    elsif ( $ex eq 'vimeo' ) {
+        $uploader_url = 'https://vimeo.com/';
+    }
     if ( defined $uploader_url ) {
         $uploader_url .= $uploader_id;
         if ( none{ $uploader_url eq $_ } keys %{$opt->{sticky}} ) {
@@ -220,7 +251,7 @@ sub add_uploader_to_history {
 }
 
 
-sub write_uploader_history_to_file {
+sub new_uploader_to_history_file {
     my ( $opt ) = @_;
     my $c_hist = $opt->{history};
     my @keys = sort { $c_hist->{$b}{timestamp} <=> $c_hist->{$a}{timestamp} } keys %$c_hist;
